@@ -19,14 +19,14 @@ use overload
   ;
 
 # ABSTRACT: Wasmtime function class
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 $ffi_prefix = 'wasm_func_';
 $ffi->load_custom_type('::PtrObject' => 'wasm_func_t' => __PACKAGE__);
 
 
-$ffi->attach( new => ['wasm_store_t', 'wasm_functype_t', '(opaque,opaque)->opaque'] => 'wasm_func_t' => sub {
+$ffi->attach( [ wasmtime_func_new => 'new' ] => ['wasm_store_t', 'wasm_functype_t', '(opaque,opaque,opaque)->opaque'] => 'wasm_func_t' => sub {
   my $xsub = shift;
   my $class = shift;
   if(is_blessed_ref $_[0] && $_[0]->isa('Wasm::Wasmtime::Store'))
@@ -39,8 +39,11 @@ $ffi->attach( new => ['wasm_store_t', 'wasm_functype_t', '(opaque,opaque)->opaqu
     my $param_arity  = scalar $functype->params;
     my $result_arity = scalar$functype->results;
 
+    require Wasm::Wasmtime::Caller;
     my $wrapper = $ffi->closure(sub {
-      my($params, $results) = @_;
+      my($caller, $params, $results) = @_;
+      $caller = Wasm::Wasmtime::Caller->new($caller);
+      unshift @Wasm::Wasmtime::Caller::callers, $caller;
 
       my @args = $param_arity ? do {
         my $args = Wasm::Wasmtime::ValVec->from_c($params);
@@ -55,6 +58,8 @@ $ffi->attach( new => ['wasm_store_t', 'wasm_functype_t', '(opaque,opaque)->opaqu
       if(my $error = $@)
       {
         my $trap = Wasm::Wasmtime::Trap->new($store, "$error\0");
+        delete $caller->{ptr};
+        shift @Wasm::Wasmtime::Caller::callers;
         return delete $trap->{ptr};
       }
       else
@@ -71,6 +76,8 @@ $ffi->attach( new => ['wasm_store_t', 'wasm_functype_t', '(opaque,opaque)->opaqu
             $result->of->$kind(shift @ret);
           }
         }
+        delete $caller->{ptr};
+        shift @Wasm::Wasmtime::Caller::callers;
         return undef;
       }
     });
@@ -162,7 +169,7 @@ Wasm::Wasmtime::Func - Wasmtime function class
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
